/**
 * Copyright (c) 2015-2016 Linagora
 * 
 * This program/library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 2.1 of the License, or (at your
 * option) any later version.
 * 
 * This program/library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
 * for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program/library; If not, see http://www.gnu.org/licenses/
 * for the GNU Lesser General Public License version 2.1.
 */
package org.ow2.petals.commons.xml;

import java.io.ByteArrayInputStream;
import java.io.InputStream;
import java.io.InputStreamReader;
import java.io.Reader;
import java.io.Serializable;

import javax.xml.transform.stream.StreamSource;

/**
 * A helper class which provides a JAXP {@link javax.xml.transform.Source Source} from a byte[] which can be read as
 * many times as required.
 * 
 * This class is heavily inspired by Apache Camel's BytesSource delivered under the Apache Licence 2, which is
 * compatible with the GPL used by Petals.
 */
public class BytesSource extends StreamSource implements Serializable {

    private static final long serialVersionUID = 124123201106542082L;

    private final byte[] data;

    public BytesSource(final byte[] data) {
        if (data == null) {
            throw new IllegalArgumentException("data must be specified");
        }
        this.data = data;
    }

    public BytesSource(final byte[] data, final String systemId) {
        this(data);
        setSystemId(systemId);
    }

    @Override
    public InputStream getInputStream() {
        return new ByteArrayInputStream(data);
    }

    @Override
    public Reader getReader() {
        return new InputStreamReader(getInputStream());
    }

    public byte[] getData() {
        return data;
    }

    @Override
    public String toString() {
        return "BytesSource[" + new String(data) + "]";
    }
}
